EntriesOnly

Struct EntriesOnly 

pub struct EntriesOnly { /* private fields */ }
Adapter which returns just the directory entries.

This adapter mimics the earlier behavior of the crate, where referrals were collected and returned in the overall result of the Search, and nothing but directory entries were returned to the users.

To invoke a streaming Search with this adapter on the ldap handle, use

let mut stream = ldap.streaming_search_with(
    EntriesOnly::new(),
    "",
    Scope::Base,
    "(objectClass=*)",
    vec!["+"]
);

Implementations

Source

impl EntriesOnly

Create a new adapter instance.

pub fn new() -> Self