pub struct PasswordModify<'a> {
pub user_id: Option<&'a str>,
pub old_pass: Option<&'a str>,
pub new_pass: Option<&'a str>,
}Expand description
Password Modify extended operation (RFC 3062).
The structure contains elements of a Password Modify request. The precise semantics of having a particular field present or absent will depend on the server receiving the request; consult the server documentation. Some rules are prescribed by the RFC and should generally apply:
-
The
user_idfield contains the identity of the user whose password is being changed. This may or may not be a DN. If the field is absent, the identity associated with the current connection will be used. -
If
old_passis present, it must match the existing password. -
If
new_passis not present, the server may autogenerate the new password.
Although the specification doesn’t constrain the values of old and new passwords, this implementation limits them to UTF-8 strings.
Fields
user_id: Option<&'a str>old_pass: Option<&'a str>new_pass: Option<&'a str>Trait Implementations
Sourceimpl<'a> Clone for PasswordModify<'a>
impl<'a> Clone for PasswordModify<'a>
Sourcefn clone(&self) -> PasswordModify<'a>
fn clone(&self) -> PasswordModify<'a>
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more